const textEncoder = /* @__PURE__ */ new TextEncoder();
const textDecoder = /* @__PURE__ */ new TextDecoder();
function base64Encode(data) {
  const encodedData = data instanceof Uint8Array ? data : textEncoder.encode(data);
  if (Uint8Array.prototype.toBase64) {
    return encodedData.toBase64();
  }
  return btoa(String.fromCodePoint(...encodedData));
}
function base64UrlEncode(data) {
  const encodedData = data instanceof Uint8Array ? data : textEncoder.encode(data);
  if (Uint8Array.prototype.toBase64) {
    return encodedData.toBase64({ alphabet: "base64url", omitPadding: true });
  }
  return btoa(String.fromCodePoint(...encodedData)).replace(/\+/g, "-").replace(/\//g, "_").replace(/=/g, "");
}
function base64Decode(str, toString) {
  const decodeToString = toString !== false;
  if (!str) {
    return decodeToString ? "" : new Uint8Array(0);
  }
  const data = Uint8Array.fromBase64 ? (
    // @ts-expect-error
    Uint8Array.fromBase64(str)
  ) : Uint8Array.from(atob(str), (b) => b.codePointAt(0));
  return decodeToString ? textDecoder.decode(data) : data;
}
function base64UrlDecode(str, toString) {
  const decodeToString = toString !== false;
  if (!str) {
    return decodeToString ? "" : new Uint8Array(0);
  }
  let data;
  if (Uint8Array.fromBase64) {
    data = Uint8Array.fromBase64(str, { alphabet: "base64url" });
  } else {
    str = str.replace(/-/g, "+").replace(/_/g, "/");
    while (str.length % 4) str += "=";
    data = Uint8Array.from(atob(str), (b) => b.codePointAt(0));
  }
  return decodeToString ? textDecoder.decode(data) : data;
}
function randomBytes(length) {
  return crypto.getRandomValues(new Uint8Array(length));
}
function concatUint8Arrays(...arrays) {
  const totalLength = arrays.reduce((length, arr) => length + arr.length, 0);
  const result = new Uint8Array(totalLength);
  let offset = 0;
  for (const arr of arrays) {
    result.set(arr, offset);
    offset += arr.length;
  }
  return result;
}
function maybeArray(item) {
  return Array.isArray(item) ? item : [item];
}
function isJWK(key) {
  return typeof key === "object" && key !== null && "kty" in key && typeof key.kty === "string";
}
function isJWKSet(key) {
  return key && typeof key === "object" && "keys" in key && Array.isArray(key.keys);
}
function assertCryptoKey(key) {
  if (!isCryptoKey(key)) {
    throw new Error("CryptoKey instance expected");
  }
}
function isCryptoKey(key) {
  return key?.[Symbol.toStringTag] === "CryptoKey";
}
const isCryptoKeyPair = (key) => key && typeof key === "object" && isCryptoKey(key.publicKey) && isCryptoKey(key.privateKey);

const index = {
  __proto__: null,
  assertCryptoKey: assertCryptoKey,
  base64Decode: base64Decode,
  base64Encode: base64Encode,
  base64UrlDecode: base64UrlDecode,
  base64UrlEncode: base64UrlEncode,
  concatUint8Arrays: concatUint8Arrays,
  isCryptoKey: isCryptoKey,
  isCryptoKeyPair: isCryptoKeyPair,
  isJWK: isJWK,
  isJWKSet: isJWKSet,
  maybeArray: maybeArray,
  randomBytes: randomBytes,
  textDecoder: textDecoder,
  textEncoder: textEncoder
};

export { isJWK as a, base64UrlEncode as b, textDecoder as c, base64UrlDecode as d, isJWKSet as e, concatUint8Arrays as f, assertCryptoKey as g, isCryptoKey as h, index as i, base64Decode as j, base64Encode as k, isCryptoKeyPair as l, maybeArray as m, randomBytes as r, textEncoder as t };
