import { i as JWK_RSA_Public } from './unjwt.D9da8HQF.mjs';

/** Header Parameters common to JWE and JWS */
interface JoseHeaderParameters {
    /** "kid" (Key ID) Header Parameter */
    kid?: string;
    /** "x5t" (X.509 Certificate SHA-1 Thumbprint) Header Parameter */
    x5t?: string;
    /** "x5c" (X.509 Certificate Chain) Header Parameter */
    x5c?: string[];
    /** "x5u" (X.509 URL) Header Parameter */
    x5u?: string;
    /** "jku" (JWK Set URL) Header Parameter */
    jku?: string;
    /** "jwk" (JSON Web Key) Header Parameter */
    jwk?: JWK_RSA_Public;
    /** "typ" (Type) Header Parameter */
    typ?: string;
    /** "cty" (Content Type) Header Parameter */
    cty?: string;
    /** "crit" (Critical) Header Parameter */
    crit?: string[];
    /** Any other JWS/JWE Header member. */
    [propName: string]: unknown;
}
interface JWTClaims {
    /** "iss" (Issuer) Claim */
    iss?: string;
    /** "sub" (Subject) Claim */
    sub?: string;
    /** "aud" (Audience) Claim */
    aud?: string | string[];
    /** "exp" (Expiration Time) Claim */
    exp?: number;
    /** "nbf" (Not Before) Claim */
    nbf?: number;
    /** "iat" (Issued At) Claim */
    iat?: number;
    /** "jti" (JWT ID) Claim */
    jti?: string;
    /** Any other JWT member. */
    [propName: string]: unknown;
}
interface JWT<T = JWTClaims> {
    header: JoseHeaderParameters & {
        /** "alg" (Algorithm) Header Parameter */
        alg: string;
    };
    claims: T;
}

export type { JoseHeaderParameters as J, JWTClaims as a, JWT as b };
